@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:51:10
-@LastEditTime: 2021-09-17 17:51:32
+@LastEditTime: 2021-10-10 15:38:07
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -14,8 +14,6 @@ class AppExpireHandler(ClientBaseHandler):
     """
     :description: 获取小程序是否过期未续费
     """
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取小程序是否过期未续费
