@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-11-17 15:32:52
+@LastEditTime: 2021-12-02 18:33:51
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -183,6 +183,35 @@ class ApplyBlackUnbindHandler(ClientBaseHandler):
             return self.response_json_success()
 
 
+class GetUnbindApplyHandler(ClientBaseHandler):
+    """
+    :description: 获取黑名单解封申请记录
+    """
+    @filter_check_params("act_id,tb_user_id")
+    def get_async(self):
+        """
+        :description: 获取黑名单解封申请记录
+        :param act_id:活动标识
+        :param tb_user_id:用户标识
+        :param reason:解封理由
+        :return 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
+        act_id = int(self.get_param("act_id", 0))
+        user_id = self.get_user_id()
+        reason = self.get_param("reason", "误封号,申请解封")
+
+        invoke_result_data = InvokeResultData()
+        user_base_model = UserBaseModel(context=self)
+        invoke_result_data = user_base_model.get_black_info_dict(app_id, act_id, user_id)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        else:
+            return self.response_json_success()
+
+
 class GetCouponPrizeHandler(ClientBaseHandler):
     """
     :description: 领取淘宝优惠券
@@ -291,8 +320,17 @@ class AssetLogListHandler(ClientBaseHandler):
         asset_type = int(self.get_param("asset_type", 0))
         asset_object_id = self.get_param("asset_object_id")
 
+        field = "*"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        else:
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
-        return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id))
+        page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field)
+        ref_params = {}
+        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        return self.response_json_success(page_info)
 
 
 class GetJoinMemberUrlHandler(ClientBaseHandler):
