@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-11-11 10:53:40
+@LastEditTime: 2021-12-01 10:19:40
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -146,7 +146,7 @@ class SevenHelper:
         return False
 
     @classmethod
-    def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names=''):
+    def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names='', exclude_merge_columns_names=''):
         """
         :description: 两个字典列表合并
         :param source_dict_list：源字典表
@@ -154,6 +154,7 @@ class SevenHelper:
         :param merge_dict_list：需要合并的字典表
         :param merge_key：需要合并的字典表用来关联的字段
         :param merge_columns_names：需要合并的字典表中需要展示的字段
+        :param exclude_merge_columns_names：需要合并的字典表中不需要展示的字段
         :return: 
         :last_editors: HuangJianYi
         """
@@ -162,7 +163,9 @@ class SevenHelper:
             list_key = list(merge_columns_names.split(","))
         else:
             list_key = list(merge_dict_list[0].keys()) if len(merge_dict_list)>0 else []
-
+        if exclude_merge_columns_names:
+            exclude_key = list(exclude_merge_columns_names.split(","))
+            list_key = list(set(list_key).difference(set(exclude_key)))
         for source_dict in source_dict_list:
             info_list = [i for i in merge_dict_list if source_dict[source_key] and str(i[merge_key]) == str(source_dict[source_key])]
             if info_list:
