@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-11-23 14:15:22
+@LastEditTime: 2021-12-02 17:57:41
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -366,7 +366,7 @@ class AssetBaseModel():
                 user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
-    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id="", field="*",is_cache=True):
+    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*",is_cache=True):
         """
         :description: 获取用户资产流水记录
         :param app_id：应用标识
@@ -419,8 +419,13 @@ class AssetBaseModel():
             condition += " AND source_type=%s"
             params.append(source_type)
         if source_object_id:
-            condition += " AND source_object_id=%s"
-            params.append(source_object_id)
+            if type(source_object_id) == str:
+                condition += " AND " + SevenHelper.get_condition_by_str_list("source_object_id",source_object_id.split(","))
+            elif type(source_object_id) == list:
+                condition += " AND " + SevenHelper.get_condition_by_str_list("source_object_id",source_object_id)
+            else:
+                condition += " AND source_object_id=%s"
+                params.append(source_object_id)
         sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
         asset_log_model = AssetLogModel(sub_table=sub_table, context=self.context)
         if is_cache:
