@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-10-12 17:56:15
+@LastEditTime: 2021-11-10 09:16:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -33,14 +33,9 @@ class AssetConsoleModel():
             self._start_process_asset_inventory_warn(None, mod_count)
 
         else:
-
             for i in range(sub_table_count):
-
-                t = multiprocessing.Process(target=self._start_process_user_asset_warn, args=[str(i), mod_count])
-                t.start()
-
-                j = multiprocessing.Process(target=self._start_process_asset_inventory_warn, args=[str(i), mod_count])
-                j.start()
+                self._start_process_user_asset_warn(str(i), mod_count)
+                self._start_process_asset_inventory_warn(str(i), mod_count)
 
         l = threading.Thread(target=self._process_onlyid_warn, args=[])
         l.start()
@@ -115,9 +110,9 @@ class AssetConsoleModel():
                             logger_error.error(f"用户资产负数预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_log)},ex:{traceback.format_exc()}")
                             continue
                 else:
-                    time.sleep(10)
+                    time.sleep(1)
             except Exception as ex:
-                time.sleep(10)
+                time.sleep(5)
 
     def _process_onlyid_warn(self):
         """
@@ -132,7 +127,7 @@ class AssetConsoleModel():
                 hash_name_1 = f"warn_handler_list_{str(SevenHelper.get_now_int(fmt='%Y%m%d'))}"
                 hkeys = redis_init.hkeys(hash_name_1)
                 if len(hkeys)<=0:
-                    time.sleep(10)
+                    time.sleep(1)
                     continue
                 for key in hkeys:
                     date_start = TimeHelper.format_time_to_datetime(format='%Y-%m-%d %H:%M')
@@ -170,7 +165,7 @@ class AssetConsoleModel():
                     asset_warn_notice_model.add_entity(asset_warn_notice)
                 time.sleep(5*60)
             except Exception as ex:
-                time.sleep(10)
+                time.sleep(5)
 
     def _push_warn_notice(self):
         """
@@ -204,7 +199,7 @@ class AssetConsoleModel():
                             continue
                 time.sleep(1)
             except Exception as ex:
-                time.sleep(10)
+                time.sleep(5)
 
     def _process_asset_inventory_warn(self, sub_table, mod_value, mod_count):
         """
@@ -262,4 +257,4 @@ class AssetConsoleModel():
                 else:
                     time.sleep(60 * 60)
             except Exception as ex:
-                time.sleep(10)
+                time.sleep(5)
