@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-10-09 10:57:45
+@LastEditTime: 2021-11-26 10:40:52
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -57,7 +57,7 @@ class PrizeBaseModel():
                 return None
         return act_prize_dict
 
-    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],is_cache=True):
+    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],field="*",is_cache=True):
         """
         :description: 获取活动奖品列表
         :param app_id: 应用标识
@@ -71,14 +71,15 @@ class PrizeBaseModel():
         :param order_by：排序
         :param condition：条件
         :param params：参数化数组
+        :param field:查询字段
         :param is_cache: 是否缓存
         :return: 
         :last_editors: HuangJianYi
         """
-        where = "app_id=%s AND act_id=%s"
+        where = "app_id=%s and act_id=%s"
         params_list = [app_id,act_id]
         if condition:
-            where += " AND " + condition
+            where += " and " + condition
             params_list.extend(params)
         if ascription_type !=0:
             where += " and ascription_type=%s"
@@ -94,9 +95,9 @@ class PrizeBaseModel():
             params_list.append(prize_name)
         act_prize_model = ActPrizeModel(context=self.context)
         if is_cache:
-            page_list, total = act_prize_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_prize_list:actid_{act_id}")
+            page_list, total = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_prize_list:actid_{act_id}")
         else:
-            page_list, total = act_prize_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)    
+            page_list, total = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)    
         return page_list, total
 
     def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,surplus,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
@@ -254,13 +255,14 @@ class PrizeBaseModel():
             tao_coupon = TaoCoupon()
         tao_coupon.app_id = app_id
         tao_coupon.act_id = act_id
+        tao_coupon.prize_id = prize_id
         tao_coupon.coupon_type = coupon_type
         tao_coupon.right_ename = right_ename
         tao_coupon.pool_id = pool_id
         tao_coupon.coupon_start_date = coupon_start_date if coupon_start_date else "1900-01-01 00:00:00"
         tao_coupon.coupon_end_date = coupon_end_date if coupon_end_date else "2900-01-01 00:00:00"
         tao_coupon.modify_date = SevenHelper.get_now_datetime()
-        tao_coupon_model.add_update_entity(tao_coupon)
+        tao_coupon_model.add_update_entity(tao_coupon, update_sql="coupon_type=%s,right_ename=%s,pool_id=%s,coupon_start_date=%s,coupon_end_date=%s,modify_date=%s",params=[coupon_type,right_ename,pool_id,coupon_start_date,coupon_end_date,tao_coupon.modify_date])
         return invoke_result_data
 
     def update_act_prize_status(self,app_id,prize_id,is_del):
