@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2021-11-25 10:38:34
+@LastEditTime: 2021-11-30 17:05:47
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -91,9 +91,8 @@ class ThemeBaseModel():
         """
         where = ""
         params = []
-        if not theme_id or not theme_out_id:
+        if not theme_id:
             return []
-
         if theme_id:
             where = "theme_id=%s"
             params.append(theme_id)
