@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-11-01 13:33:56
+@LastEditTime: 2021-12-02 15:41:38
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -164,7 +164,7 @@ class TopBaseModel():
 
     def version_upgrade(self, app_id, client_template_id, client_ver, access_token,app_key, app_secret, app_info, is_log=False):
         """
-        :description: app更新
+        :description: app更新 接口权限包：商家应用-模板实例化权限包
         :param app_id:app_id
         :param client_template_id:模板id
         :param client_ver:更新的版本号
