@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-11-26 17:50:47
+@LastEditTime: 2021-12-02 20:20:03
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -38,6 +38,28 @@ class UserBaseModel(FrameBaseModel):
             return 0
         return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
 
+    def get_user_black_dependency_key(self, act_id, user_id):
+        """
+        :description: 获取用户黑名单缓存key
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        return f"user_black:{act_id}_{user_id}"
+
+    def _delete_user_black_cache(self,act_id,user_id):
+        """
+        :description: 删除用户黑名单缓存
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        cache_key = self.get_user_black_dependency_key(act_id,user_id)
+        redis_init = SevenHelper.redis_init()
+        redis_init.delete(cache_key)
+
     def get_user_info_dependency_key(self, act_id, id_md5, open_id=""):
         """
         :description: 获取用户信息缓存key
@@ -84,7 +106,6 @@ class UserBaseModel(FrameBaseModel):
             if is_cache:
                 user_info_dict = user_info_model.get_cache_dict("id_md5=%s",params=[id_md5],dependency_key=dependency_key)
             else:
-                
                 user_info_dict = user_info_model.get_dict("id_md5=%s",params=[id_md5])
         else:
             if is_cache:
@@ -116,10 +137,8 @@ class UserBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, 0, [])
         if not act_id:
             return page_info
-
         condition = "act_id=%s"
         params = [act_id]
-
         if app_id:
             condition += " AND app_id=%s"
             params.append(app_id)
@@ -141,10 +160,9 @@ class UserBaseModel(FrameBaseModel):
         if end_date:
             condition += " AND create_date<=%s"
             params.append(end_date)
-
         page_list, total = UserInfoModel(context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
-
         page_info = PageInfo(page_index, page_size, total, page_list)
+        return page_info
     
     def get_join_member_url(self,access_token,app_key,app_secret,is_log):
         """
@@ -366,46 +384,42 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-
-        id_md5 = self._get_user_info_id_md5(act_id, user_id)
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         user_info_model = UserInfoModel(db_transaction=db_transaction,context=self.context)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
-
-        user_info = user_info_model.get_entity("id_md5=%s",params=[id_md5])
-        if not user_info:
+        
+        user_info_dict = self.get_user_info_dict(app_id,act_id,user_id)
+        if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "用户信息不存在"
             return invoke_result_data
-        if user_info.app_id != app_id:
+        if user_info_dict["app_id"] != app_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
-        if user_info.user_state == 1:
+        if user_info_dict["user_state"] == 1:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "该用户已是黑名单"
             return invoke_result_data
         modify_date = SevenHelper.get_now_datetime()
-        user_info.user_state = 1
-        user_info.modify_date = modify_date
-
-        user_black = user_black_model.get_entity("act_id=%s and user_id=%s", params=[user_info.act_id, user_info.user_id])
+        user_info_dict["user_state"] = 1
+        user_info_dict["modify_date"] = modify_date
 
+        user_black = user_black_model.get_entity("act_id=%s and user_id=%s", params=[act_id,user_id])
         try:
             db_transaction.begin_transaction()
-
-            user_info_model.update_entity(user_info, "user_state,modify_date")
+            user_info_model.update_table("user_state=%s,modify_date=%s","id=%s",params=[user_info_dict["user_state"],user_info_dict["modify_date"],user_info_dict["id"]])
             if not user_black:
                 #添加到用户黑名单管理表
                 user_black = UserBlack()
-                user_black.app_id = user_info.app_id
-                user_black.act_id = user_info.act_id
-                user_black.user_id = user_info.user_id
-                user_black.open_id = user_info.open_id
-                user_black.user_nick = user_info.user_nick
+                user_black.app_id = user_info_dict["app_id"]
+                user_black.act_id = user_info_dict["act_id"]
+                user_black.user_id = user_info_dict["user_id"]
+                user_black.open_id = user_info_dict["open_id"]
+                user_black.user_nick = user_info_dict["user_nick"]
                 user_black.black_type = 2
                 user_black.refund_order_data = []
                 user_black.create_date = SevenHelper.get_now_datetime()
@@ -415,16 +429,15 @@ class UserBaseModel(FrameBaseModel):
                 user_black.black_type = 2
                 user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.update_entity(user_black)
-
             result = db_transaction.commit_transaction()
             if not result:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "fail"
                 invoke_result_data.error_message = "系统繁忙,请稍后再试"
                 return invoke_result_data
-            invoke_result_data.data = {"user_info":user_info.__dict__}
-            self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
-
+            invoke_result_data.data = {"user_info":user_info_dict}
+            self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
+            self._delete_user_black_cache(act_id,user_id)
         except Exception as ex:
             if db_transaction.is_transaction == True:
                 db_transaction.rollback_transaction()
@@ -451,7 +464,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-        user_info_dict = self.get_user_info_dict(act_id,user_id,open_id)
+        user_info_dict = self.get_user_info_dict(app_id,act_id,user_id,open_id)
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -469,7 +482,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "账号正常,无需申请解封"
             return invoke_result_data
         user_black_model = UserBlackModel(context=self.context)
-        user_black = user_black_model.get_entity("act_id=%s and user_id=%s", order_by="create_date desc", params=[act_id, user_id])
+        user_black = user_black_model.get_cache_entity("act_id=%s and user_id=%s", order_by="create_date desc", params=[act_id, user_id],dependency_key=self.get_user_black_dependency_key(act_id,user_id))
         if not user_black:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -484,6 +497,7 @@ class UserBaseModel(FrameBaseModel):
         user_black.audit_status = 1
         user_black.reason = reason
         user_black_model.update_entity(user_black, "audit_status,reason")
+        self._delete_user_black_cache(act_id,user_id)
         return invoke_result_data
     
     def audit_user_black(self,app_id,black_id,audit_status,audit_remark=""):
@@ -547,7 +561,7 @@ class UserBaseModel(FrameBaseModel):
          
         invoke_result_data.data = {"user_info":user_info.__dict__}
         self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
-        
+        self._delete_user_black_cache(black_info.act_id, black_info.user_id)
         return invoke_result_data
 
     def update_audit_remark(self,app_id,black_id,audit_remark):
@@ -578,6 +592,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
         user_black_model.update_table("audit_remark=%s", "id=%s", [audit_remark,black_id])
+        self._delete_user_black_cache(black_info.act_id,black_info.user_id)
         return invoke_result_data        
         
     def get_black_info_dict(self, app_id, act_id, user_id,is_cache=True):
@@ -600,7 +615,7 @@ class UserBaseModel(FrameBaseModel):
         params = [act_id, user_id]
         user_black_model = UserBlackModel(context=self.context)
         if is_cache:
-            user_black_dict = user_black_model.get_cache_dict(dependency_key=f"user_black:{act_id}_{user_id}",where=where, params=params)
+            user_black_dict = user_black_model.get_cache_dict(where=where, params=params,dependency_key=self.get_user_black_dependency_key(act_id,user_id))
         else:
             user_black_dict = user_black_model.get_dict(where, params=params)
         return user_black_dict       
